#include "dynare2.h"

void hermite_set(int, double*, double*);

typedef void (*Integrand)(const double *, double *);

void gauss_hermite_quadrature(int ndim, int order, int ncomp, Integrand integrand, double* integral)
{
  int index[ndim];
  int* pindex;
  int order1 = order+1;
  double xtab[order1], weight[order1]; // hermit_set Fortran index starts 1
  double results[ndim], xx[ndim];;
  double* pxtab;
  double* pweight;
  double* pxx;


  hermite_set(order, xtab, weight);

  for(double* pintegral = integral; pintegral < integral+ncomp; ++pintegral) 
    {
      *pintegral = 0.0;
    }

  for(pindex = index; pindex < index+ndim; ++pindex) *pindex = 1;
  for(pxx = xx; pxx < xx+ndim; ++pxx) *pxx = xtab[1];
  
  bool finish = false;

  double w1 = 1.0;
  for ( int i=0; i < ndim-1; ++i)
    {
      w1 *= weight[1];
    }
  double w2 = weight[1]*w1;
      
  while( finish != true)
    {
      integrand(xx, results);
      double* presults = results;
      for(double* pintegral=integral; pintegral < integral+ncomp; ++ pintegral)
	{
	  *pintegral += *(presults++) * w2;
	}
      int* pindex1 = index+ndim-1;
      int index2 = ndim-1;
      ++ *pindex1;
      while (*pindex1 > order)
	{
	  *pindex1 = 1;
	  --pindex1;
	  if (pindex1 < index) return;
	  --index2;
	  ++ *pindex1;
	}
      pxx = xx+index2;
      if (index2 < ndim-1)
	{
	  w1 = 1.0;
	  for (int* pindex2 = index; pindex2 < index+index2; ++pindex2)
	    {
	      w1 *= weight[*pindex2];
	    }

	  while( pindex1 < index+ndim-1)
	    {
	      *(pxx++) = xtab[*pindex1];
	      w1 *= weight[*(pindex1++)];
	    }
	}      
      *pxx = xtab[*pindex1];
      w2 = weight[*pindex1] * w1;
    }
}


//
//*****************************************************************************
//
// HERMITE_SET sets abscissas and weights for Hermite quadrature.
//
//
//  Integration interval:
//
//    ( -Infinity, +Infinity )
//
//  Weight function:
//
//    EXP ( - X**2 )
//
//  Integral to approximate:
//
//    Integral ( -INFINITY < X < +INFINITY ) EXP ( - X**2 ) * F(X) dX
//
//  Approximate integral:
//
//    Sum ( 1 <= I <= NORDER ) WEIGHT(I) * F ( XTAB(I) ).
//
// Translated to C++ by M. Juillard
//    21 July 2004
//
//  Modified:
//
//    06 December 2000
//
//  Author:
//
//    John Burkardt
//
//  Reference:
//
//    Abramowitz and Stegun,
//    Handbook of Mathematical Functions,
//    National Bureau of Standards, 1964.
//
//    Vladimir Krylov,
//    Approximate Calculation of Integrals,
//    MacMillan, 1962.
//
//    Arthur Stroud and Don Secrest,
//    Gaussian Quadrature Formulas,
//    Prentice Hall, 1966.
//
//    Daniel Zwillinger, editor,
//    Standard Mathematical Tables and Formulae,
//    30th Edition,
//    CRC Press, 1996.
//
//  Parameters:
//
//    Input, integer NORDER, the order of the rule.
//    NORDER must be between 1 and 20, or one of the values
//    30, 32, 40, 50, 60 or 64.
//
//    Output, double precision XTAB(NORDER), the abscissas of the rule,
//    which are symmetrically placed around 0.
//
//    Output, double precision WEIGHT(NORDER), the weights of the rule.
//    The weights are positive and symmetric, and should sum
//    to SQRT(PI).
//
//
//

static  double   d_pi = 3.14159265358979323846264338327950288419716939937510;

void hermite_set ( const int norder, double* xtab, double* weight )
{
  if ( norder == 1 ) 
    {

      xtab[1] = 0.0;

      weight[1] = sqrt ( d_pi );

    }
  else if ( norder == 2 )
    {

      xtab[1] = - 0.707106781186547524400844362105e+00;
      xtab[2] =   0.707106781186547524400844362105e+00;

      weight[1] = 0.886226925452758013649083741671e+00;
      weight[2] = 0.886226925452758013649083741671e+00;

    }
  else if ( norder == 3 ) 
    {

      xtab[1] = - 0.122474487139158904909864203735e+01;
      xtab[2] =   0.0e+00;
      xtab[3] =   0.122474487139158904909864203735e+01;

      weight[1] = 0.295408975150919337883027913890e+00;
      weight[2] = 0.118163590060367735153211165556e+01;
      weight[3] = 0.295408975150919337883027913890e+00;

    }
  else if ( norder == 4 ) 
    {

      xtab[1] = - 0.165068012388578455588334111112e+01;
      xtab[2] = - 0.524647623275290317884060253835e+00;
      xtab[3] =   0.524647623275290317884060253835e+00;
      xtab[4] =   0.165068012388578455588334111112e+01;

      weight[1] = 0.813128354472451771430345571899e-01;
      weight[2] = 0.804914090005512836506049184481e+00;
      weight[3] = 0.804914090005512836506049184481e+00;
      weight[4] = 0.813128354472451771430345571899e-01;

    }
  else if ( norder == 5 ) 
    {

      xtab[1] = - 0.202018287045608563292872408814e+01;
      xtab[2] = - 0.958572464613818507112770593893e+00;
      xtab[3] =   0.0e+00;
      xtab[4] =   0.958572464613818507112770593893e+00;
      xtab[5] =   0.202018287045608563292872408814e+01;

      weight[1] = 0.199532420590459132077434585942e-01;
      weight[2] = 0.393619323152241159828495620852e+00;
      weight[3] = 0.945308720482941881225689324449e+00;
      weight[4] = 0.393619323152241159828495620852e+00;
      weight[5] = 0.199532420590459132077434585942e-01;

    }
  else if ( norder == 6 ) 
    {

      xtab[1] = - 0.235060497367449222283392198706e+01;
      xtab[2] = - 0.133584907401369694971489528297e+01;
      xtab[3] = - 0.436077411927616508679215948251e+00;
      xtab[4] =   0.436077411927616508679215948251e+00;
      xtab[5] =   0.133584907401369694971489528297e+01;
      xtab[6] =   0.235060497367449222283392198706e+01;

      weight[1] = 0.453000990550884564085747256463e-02;
      weight[2] = 0.157067320322856643916311563508e+00;
      weight[3] = 0.724629595224392524091914705598e+00;
      weight[4] = 0.724629595224392524091914705598e+00;
      weight[5] = 0.157067320322856643916311563508e+00;
      weight[6] = 0.453000990550884564085747256463e-02;

    }
  else if ( norder == 7 ) 
    {

      xtab[1] = - 0.265196135683523349244708200652e+01;
      xtab[2] = - 0.167355162876747144503180139830e+01;
      xtab[3] = - 0.816287882858964663038710959027e+00;
      xtab[4] =   0.0e+00;
      xtab[5] =   0.816287882858964663038710959027e+00;
      xtab[6] =   0.167355162876747144503180139830e+01;
      xtab[7] =   0.265196135683523349244708200652e+01;

      weight[1] = 0.971781245099519154149424255939e-03;
      weight[2] = 0.545155828191270305921785688417e-01;
      weight[3] = 0.425607252610127800520317466666e+00;
      weight[4] = 0.810264617556807326764876563813e+00;
      weight[5] = 0.425607252610127800520317466666e+00;
      weight[6] = 0.545155828191270305921785688417e-01;
      weight[7] = 0.971781245099519154149424255939e-03;

    }
  else if ( norder == 8 ) 
    {

      xtab[1] = - 0.293063742025724401922350270524e+01;
      xtab[2] = - 0.198165675669584292585463063977e+01;
      xtab[3] = - 0.115719371244678019472076577906e+01;
      xtab[4] = - 0.381186990207322116854718885584e+00;
      xtab[5] =   0.381186990207322116854718885584e+00;
      xtab[6] =   0.115719371244678019472076577906e+01;
      xtab[7] =   0.198165675669584292585463063977e+01;
      xtab[8] =   0.293063742025724401922350270524e+01;

      weight[1] = 0.199604072211367619206090452544e-03;
      weight[2] = 0.170779830074134754562030564364e-01;
      weight[3] = 0.207802325814891879543258620286e+00;
      weight[4] = 0.661147012558241291030415974496e+00;
      weight[5] = 0.661147012558241291030415974496e+00;
      weight[6] = 0.207802325814891879543258620286e+00;
      weight[7] = 0.170779830074134754562030564364e-01;
      weight[8] = 0.199604072211367619206090452544e-03;

    }
  else if ( norder == 9 ) 
    {

      xtab[1] = - 0.319099320178152760723004779538e+01;
      xtab[2] = - 0.226658058453184311180209693284e+01;
      xtab[3] = - 0.146855328921666793166701573925e+01;
      xtab[4] = - 0.723551018752837573322639864579e+00;
      xtab[5] =   0.0e+00;
      xtab[6] =   0.723551018752837573322639864579e+00;
      xtab[7] =   0.146855328921666793166701573925e+01;
      xtab[8] =   0.226658058453184311180209693284e+01;
      xtab[9] =   0.319099320178152760723004779538e+01;

      weight[1] = 0.396069772632643819045862946425e-04;
      weight[2] = 0.494362427553694721722456597763e-02;
      weight[3] = 0.884745273943765732879751147476e-01;
      weight[4] = 0.432651559002555750199812112956e+00;
      weight[5] = 0.720235215606050957124334723389e+00;
      weight[6] = 0.432651559002555750199812112956e+00;
      weight[7] = 0.884745273943765732879751147476e-01;
      weight[8] = 0.494362427553694721722456597763e-02;
      weight[9] = 0.396069772632643819045862946425e-04;

    }
  else if ( norder == 10 ) 
    {

      xtab[1] =  - 0.343615911883773760332672549432e+01;
      xtab[2] =  - 0.253273167423278979640896079775e+01;
      xtab[3] =  - 0.175668364929988177345140122011e+01;
      xtab[4] =  - 0.103661082978951365417749191676e+01;
      xtab[5] =  - 0.342901327223704608789165025557e+00;
      xtab[6] =    0.342901327223704608789165025557e+00;
      xtab[7] =    0.103661082978951365417749191676e+01;
      xtab[8] =    0.175668364929988177345140122011e+01;
      xtab[9] =    0.253273167423278979640896079775e+01;
      xtab[10] =   0.343615911883773760332672549432e+01;

      weight[1] =  0.764043285523262062915936785960e-05;
      weight[2] =  0.134364574678123269220156558585e-02;
      weight[3] =  0.338743944554810631361647312776e-01;
      weight[4] =  0.240138611082314686416523295006e+00;
      weight[5] =  0.610862633735325798783564990433e+00;
      weight[6] =  0.610862633735325798783564990433e+00;
      weight[7] =  0.240138611082314686416523295006e+00;
      weight[8] =  0.338743944554810631361647312776e-01;
      weight[9] =  0.134364574678123269220156558585e-02;
      weight[10] = 0.764043285523262062915936785960e-05;

    }
  else if ( norder == 11 ) 
    {

      xtab[1] =  - 0.366847084655958251845837146485e+01;
      xtab[2] =  - 0.278329009978165177083671870152e+01;
      xtab[3] =  - 0.202594801582575533516591283121e+01;
      xtab[4] =  - 0.132655708449493285594973473558e+01;
      xtab[5] =  - 0.656809566882099765024611575383e+00;
      xtab[6] =    0.0e+00;
      xtab[7] =    0.656809566882099765024611575383e+00;
      xtab[8] =    0.132655708449493285594973473558e+01;
      xtab[9] =    0.202594801582575533516591283121e+01;
      xtab[10] =   0.278329009978165177083671870152e+01;
      xtab[11] =   0.366847084655958251845837146485e+01;

      weight[1] =  0.143956039371425822033088366032e-05;
      weight[2] =  0.346819466323345510643413772940e-03;
      weight[3] =  0.119113954449115324503874202916e-01;
      weight[4] =  0.117227875167708503381788649308e+00;
      weight[5] =  0.429359752356125028446073598601e+00;
      weight[6] =  0.654759286914591779203940657627e+00;
      weight[7] =  0.429359752356125028446073598601e+00;
      weight[8] =  0.117227875167708503381788649308e+00;
      weight[9] =  0.119113954449115324503874202916e-01;
      weight[10] = 0.346819466323345510643413772940e-03;
      weight[11] = 0.143956039371425822033088366032e-05;

    }
  else if ( norder == 12 ) 
    {

      xtab[1] =  - 0.388972489786978191927164274724e+01;
      xtab[2] =  - 0.302063702512088977171067937518e+01;
      xtab[3] =  - 0.227950708050105990018772856942e+01;
      xtab[4] =  - 0.159768263515260479670966277090e+01;
      xtab[5] =  - 0.947788391240163743704578131060e+00;
      xtab[6] =  - 0.314240376254359111276611634095e+00;
      xtab[7] =    0.314240376254359111276611634095e+00;
      xtab[8] =    0.947788391240163743704578131060e+00;
      xtab[9] =    0.159768263515260479670966277090e+01;
      xtab[10] =   0.227950708050105990018772856942e+01;
      xtab[11] =   0.302063702512088977171067937518e+01;
      xtab[12] =   0.388972489786978191927164274724e+01;

      weight[1] =  0.265855168435630160602311400877e-06;
      weight[2] =  0.857368704358785865456906323153e-04;
      weight[3] =  0.390539058462906185999438432620e-02;
      weight[4] =  0.516079856158839299918734423606e-01;
      weight[5] =  0.260492310264161129233396139765e+00;
      weight[6] =  0.570135236262479578347113482275e+00;
      weight[7] =  0.570135236262479578347113482275e+00;
      weight[8] =  0.260492310264161129233396139765e+00;
      weight[9] =  0.516079856158839299918734423606e-01;
      weight[10] = 0.390539058462906185999438432620e-02;
      weight[11] = 0.857368704358785865456906323153e-04;
      weight[12] = 0.265855168435630160602311400877e-06;

    }
  else if ( norder == 13 ) 
    {

      xtab[1] =  - 0.410133759617863964117891508007e+01;
      xtab[2] =  - 0.324660897837240998812205115236e+01;
      xtab[3] =  - 0.251973568567823788343040913628e+01;
      xtab[4] =  - 0.185310765160151214200350644316e+01;
      xtab[5] =  - 0.122005503659074842622205526637e+01;
      xtab[6] =  - 0.605763879171060113080537108602e+00;
      xtab[7] =    0.0e+00;
      xtab[8] =    0.605763879171060113080537108602e+00;
      xtab[9] =    0.122005503659074842622205526637e+01;
      xtab[10] =   0.185310765160151214200350644316e+01;
      xtab[11] =   0.251973568567823788343040913628e+01;
      xtab[12] =   0.324660897837240998812205115236e+01;
      xtab[13] =   0.410133759617863964117891508007e+01;

      weight[1] =  0.482573185007313108834997332342e-07;
      weight[2] =  0.204303604027070731248669432937e-04;
      weight[3] =  0.120745999271938594730924899224e-02;
      weight[4] =  0.208627752961699392166033805050e-01;
      weight[5] =  0.140323320687023437762792268873e+00;
      weight[6] =  0.421616296898543221746893558568e+00;
      weight[7] =  0.604393187921161642342099068579e+00;
      weight[8] =  0.421616296898543221746893558568e+00;
      weight[9] =  0.140323320687023437762792268873e+00;
      weight[10] = 0.208627752961699392166033805050e-01;
      weight[11] = 0.120745999271938594730924899224e-02;
      weight[12] = 0.204303604027070731248669432937e-04;
      weight[13] = 0.482573185007313108834997332342e-07;

    }
  else if ( norder == 14 ) 
    {

      xtab[1] =  - 0.430444857047363181262129810037e+01;
      xtab[2] =  - 0.346265693360227055020891736115e+01;
      xtab[3] =  - 0.274847072498540256862499852415e+01;
      xtab[4] =  - 0.209518325850771681573497272630e+01;
      xtab[5] =  - 0.147668273114114087058350654421e+01;
      xtab[6] =  - 0.878713787329399416114679311861e+00;
      xtab[7] =  - 0.291745510672562078446113075799e+00;
      xtab[8] =    0.291745510672562078446113075799e+00;
      xtab[9] =    0.878713787329399416114679311861e+00;
      xtab[10] =   0.147668273114114087058350654421e+01;
      xtab[11] =   0.209518325850771681573497272630e+01;
      xtab[12] =   0.274847072498540256862499852415e+01;
      xtab[13] =   0.346265693360227055020891736115e+01;
      xtab[14] =   0.430444857047363181262129810037e+01;

      weight[1] =  0.862859116812515794532041783429e-08;
      weight[2] =  0.471648435501891674887688950105e-05;
      weight[3] =  0.355092613551923610483661076691e-03;
      weight[4] =  0.785005472645794431048644334608e-02;
      weight[5] =  0.685055342234652055387163312367e-01;
      weight[6] =  0.273105609064246603352569187026e+00;
      weight[7] =  0.536405909712090149794921296776e+00;
      weight[8] =  0.536405909712090149794921296776e+00;
      weight[9] =  0.273105609064246603352569187026e+00;
      weight[10] = 0.685055342234652055387163312367e-01;
      weight[11] = 0.785005472645794431048644334608e-02;
      weight[12] = 0.355092613551923610483661076691e-03;
      weight[13] = 0.471648435501891674887688950105e-05;
      weight[14] = 0.862859116812515794532041783429e-08;

    }
  else if ( norder == 15 ) 
    {

      xtab[1] =  - 0.449999070730939155366438053053e+01;
      xtab[2] =  - 0.366995037340445253472922383312e+01;
      xtab[3] =  - 0.296716692790560324848896036355e+01;
      xtab[4] =  - 0.232573248617385774545404479449e+01;
      xtab[5] =  - 0.171999257518648893241583152515e+01;
      xtab[6] =  - 0.113611558521092066631913490556e+01;
      xtab[7] =  - 0.565069583255575748526020337198e+00;
      xtab[8] =    0.0e+00;
      xtab[9] =    0.565069583255575748526020337198e+00;
      xtab[10] =   0.113611558521092066631913490556e+01;
      xtab[11] =   0.171999257518648893241583152515e+01;
      xtab[12] =   0.232573248617385774545404479449e+01;
      xtab[13] =   0.296716692790560324848896036355e+01;
      xtab[14] =   0.366995037340445253472922383312e+01;
      xtab[15] =   0.449999070730939155366438053053e+01;

      weight[1] =  0.152247580425351702016062666965e-08;
      weight[2] =  0.105911554771106663577520791055e-05;
      weight[3] =  0.100004441232499868127296736177e-03;
      weight[4] =  0.277806884291277589607887049229e-02;
      weight[5] =  0.307800338725460822286814158758e-01;
      weight[6] =  0.158488915795935746883839384960e+00;
      weight[7] =  0.412028687498898627025891079568e+00;
      weight[8] =  0.564100308726417532852625797340e+00;
      weight[9] =  0.412028687498898627025891079568e+00;
      weight[10] = 0.158488915795935746883839384960e+00;
      weight[11] = 0.307800338725460822286814158758e-01;
      weight[12] = 0.277806884291277589607887049229e-02;
      weight[13] = 0.100004441232499868127296736177e-03;
      weight[14] = 0.105911554771106663577520791055e-05;
      weight[15] = 0.152247580425351702016062666965e-08;

    }
  else if ( norder == 16 ) 
    {

      xtab[1] =  - 0.468873893930581836468849864875e+01;
      xtab[2] =  - 0.386944790486012269871942409801e+01;
      xtab[3] =  - 0.317699916197995602681399455926e+01;
      xtab[4] =  - 0.254620215784748136215932870545e+01;
      xtab[5] =  - 0.195178799091625397743465541496e+01;
      xtab[6] =  - 0.138025853919888079637208966969e+01;
      xtab[7] =  - 0.822951449144655892582454496734e+00;
      xtab[8] =  - 0.273481046138152452158280401965e+00;
      xtab[9] =    0.273481046138152452158280401965e+00;
      xtab[10] =   0.822951449144655892582454496734e+00;
      xtab[11] =   0.138025853919888079637208966969e+01;
      xtab[12] =   0.195178799091625397743465541496e+01;
      xtab[13] =   0.254620215784748136215932870545e+01;
      xtab[14] =   0.317699916197995602681399455926e+01;
      xtab[15] =   0.386944790486012269871942409801e+01;
      xtab[16] =   0.468873893930581836468849864875e+01;

      weight[1] =  0.265480747401118224470926366050e-09;
      weight[2] =  0.232098084486521065338749423185e-06;
      weight[3] =  0.271186009253788151201891432244e-04;
      weight[4] =  0.932284008624180529914277305537e-03;
      weight[5] =  0.128803115355099736834642999312e-01;
      weight[6] =  0.838100413989858294154207349001e-01;
      weight[7] =  0.280647458528533675369463335380e+00;
      weight[8] =  0.507929479016613741913517341791e+00;
      weight[9] =  0.507929479016613741913517341791e+00;
      weight[10] = 0.280647458528533675369463335380e+00;
      weight[11] = 0.838100413989858294154207349001e-01;
      weight[12] = 0.128803115355099736834642999312e-01;
      weight[13] = 0.932284008624180529914277305537e-03;
      weight[14] = 0.271186009253788151201891432244e-04;
      weight[15] = 0.232098084486521065338749423185e-06;
      weight[16] = 0.265480747401118224470926366050e-09;

    }
  else if ( norder == 17 ) 
    {

      xtab[1] =  - 0.487134519367440308834927655662e+01;
      xtab[2] =  - 0.406194667587547430689245559698e+01;
      xtab[3] =  - 0.337893209114149408338327069289e+01;
      xtab[4] =  - 0.275776291570388873092640349574e+01;
      xtab[5] =  - 0.217350282666662081927537907149e+01;
      xtab[6] =  - 0.161292431422123133311288254454e+01;
      xtab[7] =  - 0.106764872574345055363045773799e+01;
      xtab[8] =  - 0.531633001342654731349086553718e+00;
      xtab[9] =    0.0e+00;
      xtab[10] =   0.531633001342654731349086553718e+00;
      xtab[11] =   0.106764872574345055363045773799e+01;
      xtab[12] =   0.161292431422123133311288254454e+01;
      xtab[13] =   0.217350282666662081927537907149e+01;
      xtab[14] =   0.275776291570388873092640349574e+01;
      xtab[15] =   0.337893209114149408338327069289e+01;
      xtab[16] =   0.406194667587547430689245559698e+01;
      xtab[17] =   0.487134519367440308834927655662e+01;

      weight[1] =  0.458057893079863330580889281222e-10;
      weight[2] =  0.497707898163079405227863353715e-07;
      weight[3] =  0.711228914002130958353327376218e-05;
      weight[4] =  0.298643286697753041151336643059e-03;
      weight[5] =  0.506734995762753791170069495879e-02;
      weight[6] =  0.409200341495762798094994877854e-01;
      weight[7] =  0.172648297670097079217645196219e+00;
      weight[8] =  0.401826469470411956577635085257e+00;
      weight[9] =  0.530917937624863560331883103379e+00;
      weight[10] = 0.401826469470411956577635085257e+00;
      weight[11] = 0.172648297670097079217645196219e+00;
      weight[12] = 0.409200341495762798094994877854e-01;
      weight[13] = 0.506734995762753791170069495879e-02;
      weight[14] = 0.298643286697753041151336643059e-03;
      weight[15] = 0.711228914002130958353327376218e-05;
      weight[16] = 0.497707898163079405227863353715e-07;
      weight[17] = 0.458057893079863330580889281222e-10;

    }
  else if ( norder == 18 ) 
    {

      xtab[1] =  - 0.504836400887446676837203757885e+01;
      xtab[2] =  - 0.424811787356812646302342016090e+01;
      xtab[3] =  - 0.357376906848626607950067599377e+01;
      xtab[4] =  - 0.296137750553160684477863254906e+01;
      xtab[5] =  - 0.238629908916668600026459301424e+01;
      xtab[6] =  - 0.183553160426162889225383944409e+01;
      xtab[7] =  - 0.130092085838961736566626555439e+01;
      xtab[8] =  - 0.776682919267411661316659462284e+00;
      xtab[9] =  - 0.258267750519096759258116098711e+00;
      xtab[10] =   0.258267750519096759258116098711e+00;
      xtab[11] =   0.776682919267411661316659462284e+00;
      xtab[12] =   0.130092085838961736566626555439e+01;
      xtab[13] =   0.183553160426162889225383944409e+01;
      xtab[14] =   0.238629908916668600026459301424e+01;
      xtab[15] =   0.296137750553160684477863254906e+01;
      xtab[16] =   0.357376906848626607950067599377e+01;
      xtab[17] =   0.424811787356812646302342016090e+01;
      xtab[18] =   0.504836400887446676837203757885e+01;

      weight[1] =  0.782819977211589102925147471012e-11;
      weight[2] =  0.104672057957920824443559608435e-07;
      weight[3] =  0.181065448109343040959702385911e-05;
      weight[4] =  0.918112686792940352914675407371e-04;
      weight[5] =  0.188852263026841789438175325426e-02;
      weight[6] =  0.186400423875446519219315221973e-01;
      weight[7] =  0.973017476413154293308537234155e-01;
      weight[8] =  0.284807285669979578595606820713e+00;
      weight[9] =  0.483495694725455552876410522141e+00;
      weight[10] = 0.483495694725455552876410522141e+00;
      weight[11] = 0.284807285669979578595606820713e+00;
      weight[12] = 0.973017476413154293308537234155e-01;
      weight[13] = 0.186400423875446519219315221973e-01;
      weight[14] = 0.188852263026841789438175325426e-02;
      weight[15] = 0.918112686792940352914675407371e-04;
      weight[16] = 0.181065448109343040959702385911e-05;
      weight[17] = 0.104672057957920824443559608435e-07;
      weight[18] = 0.782819977211589102925147471012e-11;

    }
  else if ( norder == 19 ) 
    {

      xtab[1] =  - 0.522027169053748216460967142500e+01;
      xtab[2] =  - 0.442853280660377943723498532226e+01;
      xtab[3] =  - 0.376218735196402009751489394104e+01;
      xtab[4] =  - 0.315784881834760228184318034120e+01;
      xtab[5] =  - 0.259113378979454256492128084112e+01;
      xtab[6] =  - 0.204923170985061937575050838669e+01;
      xtab[7] =  - 0.152417061939353303183354859367e+01;
      xtab[8] =  - 0.101036838713431135136859873726e+01;
      xtab[9] =  - 0.503520163423888209373811765050e+00;
      xtab[10] =   0.0e+00;
      xtab[11] =   0.503520163423888209373811765050e+00;
      xtab[12] =   0.101036838713431135136859873726e+01;
      xtab[13] =   0.152417061939353303183354859367e+01;
      xtab[14] =   0.204923170985061937575050838669e+01;
      xtab[15] =   0.259113378979454256492128084112e+01;
      xtab[16] =   0.315784881834760228184318034120e+01;
      xtab[17] =   0.376218735196402009751489394104e+01;
      xtab[18] =   0.442853280660377943723498532226e+01;
      xtab[19] =   0.522027169053748216460967142500e+01;

      weight[1] =  0.132629709449851575185289154385e-11;
      weight[2] =  0.216305100986355475019693077221e-08;
      weight[3] =  0.448824314722312295179447915594e-06;
      weight[4] =  0.272091977631616257711941025214e-04;
      weight[5] =  0.670877521407181106194696282100e-03;
      weight[6] =  0.798886677772299020922211491861e-02;
      weight[7] =  0.508103869090520673569908110358e-01;
      weight[8] =  0.183632701306997074156148485766e+00;
      weight[9] =  0.391608988613030244504042313621e+00;
      weight[10] = 0.502974888276186530840731361096e+00;
      weight[11] = 0.391608988613030244504042313621e+00;
      weight[12] = 0.183632701306997074156148485766e+00;
      weight[13] = 0.508103869090520673569908110358e-01;
      weight[14] = 0.798886677772299020922211491861e-02;
      weight[15] = 0.670877521407181106194696282100e-03;
      weight[16] = 0.272091977631616257711941025214e-04;
      weight[17] = 0.448824314722312295179447915594e-06;
      weight[18] = 0.216305100986355475019693077221e-08;
      weight[19] = 0.132629709449851575185289154385e-11;

    }
  else if ( norder == 20 ) 
    {

      xtab[1] =  - 0.538748089001123286201690041068e+01;
      xtab[2] =  - 0.460368244955074427307767524898e+01;
      xtab[3] =  - 0.394476404011562521037562880052e+01;
      xtab[4] =  - 0.334785456738321632691492452300e+01;
      xtab[5] =  - 0.278880605842813048052503375640e+01;
      xtab[6] =  - 0.225497400208927552308233334473e+01;
      xtab[7] =  - 0.173853771211658620678086566214e+01;
      xtab[8] =  - 0.123407621539532300788581834696e+01;
      xtab[9] =  - 0.737473728545394358705605144252e+00;
      xtab[10] = - 0.245340708300901249903836530634e+00;
      xtab[11] =   0.245340708300901249903836530634e+00;
      xtab[12] =   0.737473728545394358705605144252e+00;
      xtab[13] =   0.123407621539532300788581834696e+01;
      xtab[14] =   0.173853771211658620678086566214e+01;
      xtab[15] =   0.225497400208927552308233334473e+01;
      xtab[16] =   0.278880605842813048052503375640e+01;
      xtab[17] =   0.334785456738321632691492452300e+01;
      xtab[18] =   0.394476404011562521037562880052e+01;
      xtab[19] =   0.460368244955074427307767524898e+01;
      xtab[20] =   0.538748089001123286201690041068e+01;

      weight[1] =  0.222939364553415129252250061603e-12;
      weight[2] =  0.439934099227318055362885145547e-09;
      weight[3] =  0.108606937076928169399952456345e-06;
      weight[4] =  0.780255647853206369414599199965e-05;
      weight[5] =  0.228338636016353967257145917963e-03;
      weight[6] =  0.324377334223786183218324713235e-02;
      weight[7] =  0.248105208874636108821649525589e-01;
      weight[8] =  0.109017206020023320013755033535e+00;
      weight[9] =  0.286675505362834129719659706228e+00;
      weight[10] = 0.462243669600610089650328639861e+00;
      weight[11] = 0.462243669600610089650328639861e+00;
      weight[12] = 0.286675505362834129719659706228e+00;
      weight[13] = 0.109017206020023320013755033535e+00;
      weight[14] = 0.248105208874636108821649525589e-01;
      weight[15] = 0.324377334223786183218324713235e-02;
      weight[16] = 0.228338636016353967257145917963e-03;
      weight[17] = 0.780255647853206369414599199965e-05;
      weight[18] = 0.108606937076928169399952456345e-06;
      weight[19] = 0.439934099227318055362885145547e-09;
      weight[20] = 0.222939364553415129252250061603e-12;

    }
  else if ( norder == 30 ) 
    {

      xtab[ 1] =   -6.86334529352989158106110835756e+00;
      xtab[ 2] =   -6.13827922012393462039499237854e+00;
      xtab[ 3] =   -5.53314715156749572511833355558e+00;
      xtab[ 4] =   -4.98891896858994394448649710633e+00;
      xtab[ 5] =   -4.48305535709251834188703761971e+00;
      xtab[ 6] =   -4.00390860386122881522787601332e+00;
      xtab[ 7] =   -3.54444387315534988692540090217e+00;
      xtab[ 8] =   -3.09997052958644174868873332237e+00;
      xtab[ 9] =   -2.66713212453561720057110646422e+00;
      xtab[10] =   -2.24339146776150407247297999483e+00;
      xtab[11] =   -1.82674114360368803883588048351e+00;
      xtab[12] =   -1.41552780019818851194072510555e+00;
      xtab[13] =   -1.00833827104672346180498960870e+00;
      xtab[14] =   -0.603921058625552307778155678757e+00;
      xtab[15] =   -0.201128576548871485545763013244e+00;
      xtab[16] =    0.201128576548871485545763013244e+00;
      xtab[17] =    0.603921058625552307778155678757e+00;
      xtab[18] =    1.00833827104672346180498960870e+00;
      xtab[19] =    1.41552780019818851194072510555e+00;
      xtab[20] =    1.82674114360368803883588048351e+00;
      xtab[21] =    2.24339146776150407247297999483e+00;
      xtab[22] =    2.66713212453561720057110646422e+00;
      xtab[23] =    3.09997052958644174868873332237e+00;
      xtab[24] =    3.54444387315534988692540090217e+00;
      xtab[25] =    4.00390860386122881522787601332e+00;
      xtab[26] =    4.48305535709251834188703761971e+00;
      xtab[27] =    4.98891896858994394448649710633e+00;
      xtab[28] =    5.53314715156749572511833355558e+00;
      xtab[29] =    6.13827922012393462039499237854e+00;
      xtab[30] =    6.86334529352989158106110835756e+00;

      weight[ 1] =   0.290825470013122622941102747365e-20;
      weight[ 2] =   0.281033360275090370876277491534e-16;
      weight[ 3] =   0.287860708054870606219239791142e-13;
      weight[ 4] =   0.810618629746304420399344796173e-11;
      weight[ 5] =   0.917858042437852820850075742492e-09;
      weight[ 6] =   0.510852245077594627738963204403e-07;
      weight[ 7] =   0.157909488732471028834638794022e-05;
      weight[ 8] =   0.293872522892298764150118423412e-04;
      weight[ 9] =   0.348310124318685523420995323183e-03;
      weight[10] =   0.273792247306765846298942568953e-02;
      weight[11] =   0.147038297048266835152773557787e-01;
      weight[12] =   0.551441768702342511680754948183e-01;
      weight[13] =   0.146735847540890099751693643152e+00;
      weight[14] =   0.280130930839212667413493211293e+00;
      weight[15] =   0.386394889541813862555601849165e+00;
      weight[16] =   0.386394889541813862555601849165e+00;
      weight[17] =   0.280130930839212667413493211293e+00;
      weight[18] =   0.146735847540890099751693643152e+00;
      weight[19] =   0.551441768702342511680754948183e-01;
      weight[20] =   0.147038297048266835152773557787e-01;
      weight[21] =   0.273792247306765846298942568953e-02;
      weight[22] =   0.348310124318685523420995323183e-03;
      weight[23] =   0.293872522892298764150118423412e-04;
      weight[24] =   0.157909488732471028834638794022e-05;
      weight[25] =   0.510852245077594627738963204403e-07;
      weight[26] =   0.917858042437852820850075742492e-09;
      weight[27] =   0.810618629746304420399344796173e-11;
      weight[28] =   0.287860708054870606219239791142e-13;
      weight[29] =   0.281033360275090370876277491534e-16;
      weight[30] =   0.290825470013122622941102747365e-20;

    }
  else if ( norder == 32 ) 
    {

      xtab[ 1] =   -7.12581390983e+00;
      xtab[ 2] =   -6.40949814927e+00;
      xtab[ 3] =   -5.81222594952e+00;
      xtab[ 4] =   -5.27555098652e+00;
      xtab[ 5] =   -4.77716450350e+00;
      xtab[ 6] =   -4.30554795335e+00;
      xtab[ 7] =   -3.85375548547e+00;
      xtab[ 8] =   -3.41716749282e+00;
      xtab[ 9] =   -2.99249082500e+00;
      xtab[10] =   -2.57724953773e+00;
      xtab[11] =   -2.16949918361e+00;
      xtab[12] =   -1.76765410946e+00;
      xtab[13] =   -1.37037641095e+00;
      xtab[14] =  -0.976500463590e+00;
      xtab[15] =  -0.584978765436e+00;
      xtab[16] =  -0.194840741569e+00;
      xtab[17] =   0.194840741569e+00;
      xtab[18] =   0.584978765436e+00;
      xtab[19] =   0.976500463590e+00;
      xtab[20] =    1.37037641095e+00;
      xtab[21] =    1.76765410946e+00;
      xtab[22] =    2.16949918361e+00;
      xtab[23] =    2.57724953773e+00;
      xtab[24] =    2.99249082500e+00;
      xtab[25] =    3.41716749282e+00;
      xtab[26] =    3.85375548547e+00;
      xtab[27] =    4.30554795335e+00;
      xtab[28] =    4.77716450350e+00;
      xtab[29] =    5.27555098652e+00;
      xtab[30] =    5.81222594952e+00;
      xtab[31] =    6.40949814927e+00;
      xtab[32] =    7.12581390983e+00;

      weight[ 1] =   0.731067642736e-22;
      weight[ 2] =   0.923173653649e-18;
      weight[ 3] =   0.119734401709e-14;
      weight[ 4] =   0.421501021125e-12;
      weight[ 5] =   0.593329146300e-10;
      weight[ 6] =   0.409883216476e-08;
      weight[ 7] =   0.157416779254e-06;
      weight[ 8] =   0.365058512955e-05;
      weight[ 9] =   0.541658406172e-04;
      weight[10] =   0.536268365526e-03;
      weight[11] =   0.365489032664e-02;
      weight[12] =   0.175534288315e-01;
      weight[13] =   0.604581309557e-01;
      weight[14] =   0.151269734076e+00;
      weight[15] =   0.277458142302e+00;
      weight[16] =   0.375238352592e+00;
      weight[17] =   0.375238352592e+00;
      weight[18] =   0.277458142302e+00;
      weight[19] =   0.151269734076e+00;
      weight[20] =   0.604581309557e-01;
      weight[21] =   0.175534288315e-01;
      weight[22] =   0.365489032664e-02;
      weight[23] =   0.536268365526e-03;
      weight[24] =   0.541658406172e-04;
      weight[25] =   0.365058512955e-05;
      weight[26] =   0.157416779254e-06;
      weight[27] =   0.409883216476e-08;
      weight[28] =   0.593329146300e-10;
      weight[29] =   0.421501021125e-12;
      weight[30] =   0.119734401709e-14;
      weight[31] =   0.923173653649e-18;
      weight[32] =   0.731067642736e-22;

    }
  else if ( norder == 40 ) 
    {

      xtab[ 1] =   -8.09876113925e+00;
      xtab[ 2] =   -7.41158253149e+00;
      xtab[ 3] =   -6.84023730525e+00;
      xtab[ 4] =   -6.32825535122e+00;
      xtab[ 5] =   -5.85409505603e+00;
      xtab[ 6] =   -5.40665424797e+00;
      xtab[ 7] =   -4.97926097855e+00;
      xtab[ 8] =   -4.56750207284e+00;
      xtab[ 9] =   -4.16825706683e+00;
      xtab[10] =   -3.77920675344e+00;
      xtab[11] =   -3.39855826586e+00;
      xtab[12] =   -3.02487988390e+00;
      xtab[13] =   -2.65699599844e+00;
      xtab[14] =   -2.29391714188e+00;
      xtab[15] =   -1.93479147228e+00;
      xtab[16] =   -1.57886989493e+00;
      xtab[17] =   -1.22548010905e+00;
      xtab[18] =  -0.874006612357e+00;
      xtab[19] =  -0.523874713832e+00;
      xtab[20] =  -0.174537214598e+00;
      xtab[21] =   0.174537214598e+00;
      xtab[22] =   0.523874713832e+00;
      xtab[23] =   0.874006612357e+00;
      xtab[24] =    1.22548010905e+00;
      xtab[25] =    1.57886989493e+00;
      xtab[26] =    1.93479147228e+00;
      xtab[27] =    2.29391714188e+00;
      xtab[28] =    2.65699599844e+00;
      xtab[29] =    3.02487988390e+00;
      xtab[30] =    3.39855826586e+00;
      xtab[31] =    3.77920675344e+00;
      xtab[32] =    4.16825706683e+00;
      xtab[33] =    4.56750207284e+00;
      xtab[34] =    4.97926097855e+00;
      xtab[35] =    5.40665424797e+00;
      xtab[36] =    5.85409505603e+00;
      xtab[37] =    6.32825535122e+00;
      xtab[38] =    6.84023730525e+00;
      xtab[39] =    7.41158253149e+00;
      xtab[40] =    8.09876113925e+00;

      weight[ 1] =   0.259104371384e-28;
      weight[ 2] =   0.854405696375e-24;
      weight[ 3] =   0.256759336540e-20;
      weight[ 4] =   0.198918101211e-17;
      weight[ 5] =   0.600835878947e-15;
      weight[ 6] =   0.880570764518e-13;
      weight[ 7] =   0.715652805267e-11;
      weight[ 8] =   0.352562079135e-09;
      weight[ 9] =   0.112123608322e-07;
      weight[10] =   0.241114416359e-06;
      weight[11] =   0.363157615067e-05;
      weight[12] =   0.393693398108e-04;
      weight[13] =   0.313853594540e-03;
      weight[14] =   0.187149682959e-02;
      weight[15] =   0.846088800823e-02;
      weight[16] =   0.293125655361e-01;
      weight[17] =   0.784746058652e-01;
      weight[18] =   0.163378732713e+00;
      weight[19] =   0.265728251876e+00;
      weight[20] =   0.338643277425e+00;
      weight[21] =   0.338643277425e+00;
      weight[22] =   0.265728251876e+00;
      weight[23] =   0.163378732713e+00;
      weight[24] =   0.784746058652e-01;
      weight[25] =   0.293125655361e-01;
      weight[26] =   0.846088800823e-02;
      weight[27] =   0.187149682959e-02;
      weight[28] =   0.313853594540e-03;
      weight[29] =   0.393693398108e-04;
      weight[30] =   0.363157615067e-05;
      weight[31] =   0.241114416359e-06;
      weight[32] =   0.112123608322e-07;
      weight[33] =   0.352562079135e-09;
      weight[34] =   0.715652805267e-11;
      weight[35] =   0.880570764518e-13;
      weight[36] =   0.600835878947e-15;
      weight[37] =   0.198918101211e-17;
      weight[38] =   0.256759336540e-20;
      weight[39] =   0.854405696375e-24;
      weight[40] =   0.259104371384e-28;

    }
  else if ( norder == 50 ) 
    {

      xtab[ 1] =   -9.18240695813e+00;
      xtab[ 2] =   -8.52277103092e+00;
      xtab[ 3] =   -7.97562236821e+00;
      xtab[ 4] =   -7.48640942986e+00;
      xtab[ 5] =   -7.03432350977e+00;
      xtab[ 6] =   -6.60864797386e+00;
      xtab[ 7] =   -6.20295251927e+00;
      xtab[ 8] =   -5.81299467542e+00;
      xtab[ 9] =   -5.43578608722e+00;
      xtab[10] =   -5.06911758492e+00;
      xtab[11] =   -4.71129366617e+00;
      xtab[12] =   -4.36097316045e+00;
      xtab[13] =   -4.01706817286e+00;
      xtab[14] =   -3.67867706252e+00;
      xtab[15] =   -3.34503831394e+00;
      xtab[16] =   -3.01549776957e+00;
      xtab[17] =   -2.68948470227e+00;
      xtab[18] =   -2.36649390430e+00;
      xtab[19] =   -2.04607196869e+00;
      xtab[20] =   -1.72780654752e+00;
      xtab[21] =   -1.41131775490e+00;
      xtab[22] =   -1.09625112896e+00;
      xtab[23] =  -0.782271729555e+00;
      xtab[24] =  -0.469059056678e+00;
      xtab[25] =  -0.156302546889e+00;
      xtab[26] =   0.156302546889e+00;
      xtab[27] =   0.469059056678e+00;
      xtab[28] =   0.782271729555e+00;
      xtab[29] =    1.09625112896e+00;
      xtab[30] =    1.41131775490e+00;
      xtab[31] =    1.72780654752e+00;
      xtab[32] =    2.04607196869e+00;
      xtab[33] =    2.36649390430e+00;
      xtab[34] =    2.68948470227e+00;
      xtab[35] =    3.01549776957e+00;
      xtab[36] =    3.34503831394e+00;
      xtab[37] =    3.67867706252e+00;
      xtab[38] =    4.01706817286e+00;
      xtab[39] =    4.36097316045e+00;
      xtab[40] =    4.71129366617e+00;
      xtab[41] =    5.06911758492e+00;
      xtab[42] =    5.43578608722e+00;
      xtab[43] =    5.81299467542e+00;
      xtab[44] =    6.20295251927e+00;
      xtab[45] =    6.60864797386e+00;
      xtab[46] =    7.03432350977e+00;
      xtab[47] =    7.48640942986e+00;
      xtab[48] =    7.97562236821e+00;
      xtab[49] =    8.52277103092e+00;
      xtab[50] =    9.18240695813e+00;

      weight[ 1] =   0.183379404857e-36;
      weight[ 2] =   0.167380166790e-31;
      weight[ 3] =   0.121524412340e-27;
      weight[ 4] =   0.213765830835e-24;
      weight[ 5] =   0.141709359957e-21;
      weight[ 6] =   0.447098436530e-19;
      weight[ 7] =   0.774238295702e-17;
      weight[ 8] =   0.809426189344e-15;
      weight[ 9] =   0.546594403180e-13;
      weight[10] =   0.250665552389e-11;
      weight[11] =   0.811187736448e-10;
      weight[12] =   0.190904054379e-08;
      weight[13] =   0.334679340401e-07;
      weight[14] =   0.445702996680e-06;
      weight[15] =   0.458168270794e-05;
      weight[16] =   0.368401905377e-04;
      weight[17] =   0.234269892109e-03;
      weight[18] =   0.118901178175e-02;
      weight[19] =   0.485326382616e-02;
      weight[20] =   0.160319410684e-01;
      weight[21] =   0.430791591566e-01;
      weight[22] =   0.945489354768e-01;
      weight[23] =   0.170032455676e+00;
      weight[24] =   0.251130856331e+00;
      weight[25] =   0.305085129203e+00;
      weight[26] =   0.305085129203e+00;
      weight[27] =   0.251130856331e+00;
      weight[28] =   0.170032455676e+00;
      weight[29] =   0.945489354768e-01;
      weight[30] =   0.430791591566e-01;
      weight[31] =   0.160319410684e-01;
      weight[32] =   0.485326382616e-02;
      weight[33] =   0.118901178175e-02;
      weight[34] =   0.234269892109e-03;
      weight[35] =   0.368401905377e-04;
      weight[36] =   0.458168270794e-05;
      weight[37] =   0.445702996680e-06;
      weight[38] =   0.334679340401e-07;
      weight[39] =   0.190904054379e-08;
      weight[40] =   0.811187736448e-10;
      weight[41] =   0.250665552389e-11;
      weight[42] =   0.546594403180e-13;
      weight[43] =   0.809426189344e-15;
      weight[44] =   0.774238295702e-17;
      weight[45] =   0.447098436530e-19;
      weight[46] =   0.141709359957e-21;
      weight[47] =   0.213765830835e-24;
      weight[48] =   0.121524412340e-27;
      weight[49] =   0.167380166790e-31;
      weight[50] =   0.183379404857e-36;

    }
  else if ( norder == 60 ) 
    {

      xtab[ 1] =   -10.1591092462e+00;
      xtab[ 2] =   -9.52090367701e+00;
      xtab[ 3] =   -8.99239800140e+00;
      xtab[ 4] =   -8.52056928412e+00;
      xtab[ 5] =   -8.08518865425e+00;
      xtab[ 6] =   -7.67583993750e+00;
      xtab[ 7] =   -7.28627659440e+00;
      xtab[ 8] =   -6.91238153219e+00;
      xtab[ 9] =   -6.55125916706e+00;
      xtab[10] =   -6.20077355799e+00;
      xtab[11] =   -5.85929019639e+00;
      xtab[12] =   -5.52552108614e+00;
      xtab[13] =   -5.19842653458e+00;
      xtab[14] =   -4.87715007747e+00;
      xtab[15] =   -4.56097375794e+00;
      xtab[16] =   -4.24928643596e+00;
      xtab[17] =   -3.94156073393e+00;
      xtab[18] =   -3.63733587617e+00;
      xtab[19] =   -3.33620465355e+00;
      xtab[20] =   -3.03780333823e+00;
      xtab[21] =   -2.74180374807e+00;
      xtab[22] =   -2.44790690231e+00;
      xtab[23] =   -2.15583787123e+00;
      xtab[24] =   -1.86534153123e+00;
      xtab[25] =   -1.57617901198e+00;
      xtab[26] =   -1.28812467487e+00;
      xtab[27] =   -1.00096349956e+00;
      xtab[28] =  -0.714488781673e+00;
      xtab[29] =  -0.428500064221e+00;
      xtab[30] =  -0.142801238703e+00;
      xtab[31] =   0.142801238703e+00;
      xtab[32] =   0.428500064221e+00;
      xtab[33] =   0.714488781673e+00;
      xtab[34] =    1.00096349956e+00;
      xtab[35] =    1.28812467487e+00;
      xtab[36] =    1.57617901198e+00;
      xtab[37] =    1.86534153123e+00;
      xtab[38] =    2.15583787123e+00;
      xtab[39] =    2.44790690231e+00;
      xtab[40] =    2.74180374807e+00;
      xtab[41] =    3.03780333823e+00;
      xtab[42] =    3.33620465355e+00;
      xtab[43] =    3.63733587617e+00;
      xtab[44] =    3.94156073393e+00;
      xtab[45] =    4.24928643596e+00;
      xtab[46] =    4.56097375794e+00;
      xtab[47] =    4.87715007747e+00;
      xtab[48] =    5.19842653458e+00;
      xtab[49] =    5.52552108614e+00;
      xtab[50] =    5.85929019639e+00;
      xtab[51] =    6.20077355799e+00;
      xtab[52] =    6.55125916706e+00;
      xtab[53] =    6.91238153219e+00;
      xtab[54] =    7.28627659440e+00;
      xtab[55] =    7.67583993750e+00;
      xtab[56] =    8.08518865425e+00;
      xtab[57] =    8.52056928412e+00;
      xtab[58] =    8.99239800140e+00;
      xtab[59] =    9.52090367701e+00;
      xtab[60] =    10.1591092462e+00;

      weight[ 1] =   0.110958724796e-44;
      weight[ 2] =   0.243974758810e-39;
      weight[ 3] =   0.377162672698e-35;
      weight[ 4] =   0.133255961176e-31;
      weight[ 5] =   0.171557314767e-28;
      weight[ 6] =   0.102940599693e-25;
      weight[ 7] =   0.334575695574e-23;
      weight[ 8] =   0.651256725748e-21;
      weight[ 9] =   0.815364047300e-19;
      weight[10] =   0.692324790956e-17;
      weight[11] =   0.415244410968e-15;
      weight[12] =   0.181662457614e-13;
      weight[13] =   0.594843051597e-12;
      weight[14] =   0.148895734905e-10;
      weight[15] =   0.289935901280e-09;
      weight[16] =   0.445682277521e-08;
      weight[17] =   0.547555461926e-07;
      weight[18] =   0.543351613419e-06;
      weight[19] =   0.439428693625e-05;
      weight[20] =   0.291874190415e-04;
      weight[21] =   0.160277334681e-03;
      weight[22] =   0.731773556963e-03;
      weight[23] =   0.279132482894e-02;
      weight[24] =   0.893217836028e-02;
      weight[25] =   0.240612727660e-01;
      weight[26] =   0.547189709320e-01;
      weight[27] =   0.105298763697e+00;
      weight[28] =   0.171776156918e+00;
      weight[29] =   0.237868904958e+00;
      weight[30] =   0.279853117522e+00;
      weight[31] =   0.279853117522e+00;
      weight[32] =   0.237868904958e+00;
      weight[33] =   0.171776156918e+00;
      weight[34] =   0.105298763697e+00;
      weight[35] =   0.547189709320e-01;
      weight[36] =   0.240612727660e-01;
      weight[37] =   0.893217836028e-02;
      weight[38] =   0.279132482894e-02;
      weight[39] =   0.731773556963e-03;
      weight[40] =   0.160277334681e-03;
      weight[41] =   0.291874190415e-04;
      weight[42] =   0.439428693625e-05;
      weight[43] =   0.543351613419e-06;
      weight[44] =   0.547555461926e-07;
      weight[45] =   0.445682277521e-08;
      weight[46] =   0.289935901280e-09;
      weight[47] =   0.148895734905e-10;
      weight[48] =   0.594843051597e-12;
      weight[49] =   0.181662457614e-13;
      weight[50] =   0.415244410968e-15;
      weight[51] =   0.692324790956e-17;
      weight[52] =   0.815364047300e-19;
      weight[53] =   0.651256725748e-21;
      weight[54] =   0.334575695574e-23;
      weight[55] =   0.102940599693e-25;
      weight[56] =   0.171557314767e-28;
      weight[57] =   0.133255961176e-31;
      weight[58] =   0.377162672698e-35;
      weight[59] =   0.243974758810e-39;
      weight[60] =   0.110958724796e-44;

    }
  else if ( norder == 64 ) 
    {

      xtab[ 1] =   -10.5261231680e+00;
      xtab[ 2] =   -9.89528758683e+00;
      xtab[ 3] =   -9.37315954965e+00;
      xtab[ 4] =   -8.90724909996e+00;
      xtab[ 5] =   -8.47752908338e+00;
      xtab[ 6] =   -8.07368728501e+00;
      xtab[ 7] =   -7.68954016404e+00;
      xtab[ 8] =   -7.32101303278e+00;
      xtab[ 9] =   -6.96524112055e+00;
      xtab[10] =   -6.62011226264e+00;
      xtab[11] =   -6.28401122877e+00;
      xtab[12] =   -5.95566632680e+00;
      xtab[13] =   -5.63405216435e+00;
      xtab[14] =   -5.31832522463e+00;
      xtab[15] =   -5.00777960220e+00;
      xtab[16] =   -4.70181564741e+00;
      xtab[17] =   -4.39991716823e+00;
      xtab[18] =   -4.10163447457e+00;
      xtab[19] =   -3.80657151395e+00;
      xtab[20] =   -3.51437593574e+00;
      xtab[21] =   -3.22473129199e+00;
      xtab[22] =   -2.93735082300e+00;
      xtab[23] =   -2.65197243543e+00;
      xtab[24] =   -2.36835458863e+00;
      xtab[25] =   -2.08627287988e+00;
      xtab[26] =   -1.80551717147e+00;
      xtab[27] =   -1.52588914021e+00;
      xtab[28] =   -1.24720015694e+00;
      xtab[29] =  -0.969269423071e+00;
      xtab[30] =  -0.691922305810e+00;
      xtab[31] =  -0.414988824121e+00;
      xtab[32] =  -0.138302244987e+00;
      xtab[33] =   0.138302244987e+00;
      xtab[34] =   0.414988824121e+00;
      xtab[35] =   0.691922305810e+00;
      xtab[36] =   0.969269423071e+00;
      xtab[37] =    1.24720015694e+00;
      xtab[38] =    1.52588914021e+00;
      xtab[39] =    1.80551717147e+00;
      xtab[40] =    2.08627287988e+00;
      xtab[41] =    2.36835458863e+00;
      xtab[42] =    2.65197243543e+00;
      xtab[43] =    2.93735082300e+00;
      xtab[44] =    3.22473129199e+00;
      xtab[45] =    3.51437593574e+00;
      xtab[46] =    3.80657151395e+00;
      xtab[47] =    4.10163447457e+00;
      xtab[48] =    4.39991716823e+00;
      xtab[49] =    4.70181564741e+00;
      xtab[50] =    5.00777960220e+00;
      xtab[51] =    5.31832522463e+00;
      xtab[52] =    5.63405216435e+00;
      xtab[53] =    5.95566632680e+00;
      xtab[54] =    6.28401122877e+00;
      xtab[55] =    6.62011226264e+00;
      xtab[56] =    6.96524112055e+00;
      xtab[57] =    7.32101303278e+00;
      xtab[58] =    7.68954016404e+00;
      xtab[59] =    8.07368728501e+00;
      xtab[60] =    8.47752908338e+00;
      xtab[61] =    8.90724909996e+00;
      xtab[62] =    9.37315954965e+00;
      xtab[63] =    9.89528758683e+00;
      xtab[64] =    10.5261231680e+00;

      weight[ 1] =   0.553570653584e-48;
      weight[ 2] =   0.167974799010e-42;
      weight[ 3] =   0.342113801099e-38;
      weight[ 4] =   0.155739062462e-34;
      weight[ 5] =   0.254966089910e-31;
      weight[ 6] =   0.192910359546e-28;
      weight[ 7] =   0.786179778889e-26;
      weight[ 8] =   0.191170688329e-23;
      weight[ 9] =   0.298286278427e-21;
      weight[10] =   0.315225456649e-19;
      weight[11] =   0.235188471067e-17;
      weight[12] =   0.128009339117e-15;
      weight[13] =   0.521862372645e-14;
      weight[14] =   0.162834073070e-12;
      weight[15] =   0.395917776693e-11;
      weight[16] =   0.761521725012e-10;
      weight[17] =   0.117361674232e-08;
      weight[18] =   0.146512531647e-07;
      weight[19] =   0.149553293672e-06;
      weight[20] =   0.125834025103e-05;
      weight[21] =   0.878849923082e-05;
      weight[22] =   0.512592913577e-04;
      weight[23] =   0.250983698512e-03;
      weight[24] =   0.103632909950e-02;
      weight[25] =   0.362258697852e-02;
      weight[26] =   0.107560405098e-01;
      weight[27] =   0.272031289536e-01;
      weight[28] =   0.587399819634e-01;
      weight[29] =   0.108498349306e+00;
      weight[30] =   0.171685842349e+00;
      weight[31] =   0.232994786062e+00;
      weight[32] =   0.271377424940e+00;
      weight[33] =   0.271377424940e+00;
      weight[34] =   0.232994786062e+00;
      weight[35] =   0.171685842349e+00;
      weight[36] =   0.108498349306e+00;
      weight[37] =   0.587399819634e-01;
      weight[38] =   0.272031289536e-01;
      weight[39] =   0.107560405098e-01;
      weight[40] =   0.362258697852e-02;
      weight[41] =   0.103632909950e-02;
      weight[42] =   0.250983698512e-03;
      weight[43] =   0.512592913577e-04;
      weight[44] =   0.878849923082e-05;
      weight[45] =   0.125834025103e-05;
      weight[46] =   0.149553293672e-06;
      weight[47] =   0.146512531647e-07;
      weight[48] =   0.117361674232e-08;
      weight[49] =   0.761521725012e-10;
      weight[50] =   0.395917776693e-11;
      weight[51] =   0.162834073070e-12;
      weight[52] =   0.521862372645e-14;
      weight[53] =   0.128009339117e-15;
      weight[54] =   0.235188471067e-17;
      weight[55] =   0.315225456649e-19;
      weight[56] =   0.298286278427e-21;
      weight[57] =   0.191170688329e-23;
      weight[58] =   0.786179778889e-26;
      weight[59] =   0.192910359546e-28;
      weight[60] =   0.254966089910e-31;
      weight[61] =   0.155739062462e-34;
      weight[62] =   0.342113801099e-38;
      weight[63] =   0.167974799010e-42;
      weight[64] =   0.553570653584e-48;

  }
else
  {

    std::cout << "HERMITE_SET - Fatal error\n"
	      << "  Illegal value of NORDER = "  << norder << "\n"
	      << "  Legal values are 1 to 20,\n"
	      << "  30, 32, 40, 50, 60 and 64.\n";
    exit(1);
  }
}
